
Debug enabling
-------

**Example:**



	    <?php

		//In order to disable debug enabling add the following code in the head of your application

		error_reporting(0);

		//or set this value direcly in the php.ini making it a default setting.
		
		?>


	